pub enum Dist {
FlatArchive(FlatArchive),
Bin(Bin),
}Variants
FlatArchive(FlatArchive)
Distribute an archive of a flat install tree which includes all dependencies.{n}
The resulting archive does not include the etc directory or build dependencies.{n}
Unlike a Lux tree, dependency conflicts are not supported/handled.
Bin(Bin)
Build and distribute a standalone executable{n} which runs on systems that do not have Lua installed.