Enum Commands

pub enum Commands {
Show 32 variants Add(Add), Build(Build), Check, Config(ConfigCmd), Debug(Debug), Doc(Doc), Download(Download), Fmt, GenerateRockspec(GenerateRockspec), Info(Info), Install(Install), InstallRockspec(InstallRockspec), InstallLua, Lint, List(ListCmd), Lua(RunLua), New(NewProject), Outdated(Outdated), Pack(Pack), Path(Path), Pin(ChangePin), Purge, Remove(Remove), Run(Run), Exec(Exec), Search(Search), Test(Test), Uninstall(Uninstall), Unpin(ChangePin), Update(Update), Upload(Upload), Which(Which),
}

Variants



Add(Add)

Add a dependency to the current project.



Build(Build)

Build/compile a project.



Check

Runs luacheck in the current project.



Config(ConfigCmd)

Interact with the lux configuration.



Debug(Debug)

Internal commands for debugging Lux itself.



Doc(Doc)

Show documentation for an installed rock.



Download(Download)

Download a specific rock file from a luarocks server.



Fmt

Formats the codebase with stylua.



GenerateRockspec(GenerateRockspec)

Generate a rockspec file from a project.



Info(Info)

Show metadata for any rock.



Install(Install)

Install a rock for use on the system.



InstallRockspec(InstallRockspec)

Install a local rockspec for use on the system.



InstallLua

Manually install and manage Lua headers for various Lua versions.



Lint

[UNIMPLEMENTED] Check syntax of a rockspec.



List(ListCmd)

List currently installed rocks.



Lua(RunLua)

Run lua, with the LUA_PATH and LUA_CPATH set to the specified lux tree.



New(NewProject)

Create a new Lua project.



Outdated(Outdated)

List outdated rocks.



Pack(Pack)

Create a packed rock for distribution, packing sources or binaries.



Path(Path)

Return the currently configured package path.



Pin(ChangePin)

Pin an existing rock, preventing any updates to the package.



Purge

Remove all installed rocks from a tree.



Remove(Remove)

Remove a rock from the current project’s lux.toml dependencies.



Run(Run)

Run the current project with the provided arguments.



Exec(Exec)

Execute a command that has been installed with lux. If the command is not found, a package named after the command will be installed.



Search(Search)

Query the luarocks servers.



Test(Test)

Run the test suite in the current directory.



Uninstall(Uninstall)

Uninstall a rock from the system.



Unpin(ChangePin)

Unpins an existing rock, allowing updates to alter the package.



Update(Update)

Updates all rocks in a project.



Upload(Upload)

Upload a rockspec to the public luarocks repository.



Which(Which)

Tell which file corresponds to a given module name.