pub struct Cli {Show 19 fields
pub dev: bool,
pub server: Option<Url>,
pub extra_servers: Option<Vec<Url>>,
pub only_sources: Option<String>,
pub namespace: Option<String>,
pub lua_dir: Option<PathBuf>,
pub lua_version: Option<LuaVersion>,
pub tree: Option<PathBuf>,
pub cache_dir: Option<PathBuf>,
pub data_dir: Option<PathBuf>,
pub vendor_dir: Option<PathBuf>,
pub variables: Option<Vec<(String, String)>>,
pub verbose: bool,
pub no_progress: bool,
pub nvim: bool,
pub timeout: Option<usize>,
pub max_jobs: Option<usize>,
pub no_luarc: bool,
pub command: Commands,
}Expand description
A luxurious package manager for Lua.
Fields
dev: boolEnable the sub-repositories in luarocks servers for rockspecs of in-development versions.
server: Option<Url>Fetch rocks/rockspecs from this server (takes priority over config file).
extra_servers: Option<Vec<Url>>Fetch rocks/rockspecs from this server in addition to the main server{n} (overrides any entries in the config file).
only_sources: Option<String>Restrict downloads to paths matching the given URL.
namespace: Option<String>Specify the luarocks server namespace to use.
lua_dir: Option<PathBuf>Specify the directory in which to install Lua{n} if not found.
lua_version: Option<LuaVersion>Which Lua installation to use.{n} Valid versions are: ‘5.1’, ‘5.2’, ‘5.3’, ‘5.4’, ‘jit’ and ‘jit52’.
tree: Option<PathBuf>Which tree to operate on.
cache_dir: Option<PathBuf>Specifies the cache directory for e.g. luarocks manifests.
data_dir: Option<PathBuf>Specifies the data directory (e.g. ~/.local/share/lux).
vendor_dir: Option<PathBuf>Specifies a directory with locally vendored sources and RockSpecs.{n}
When building or installing a package with this flag,{n}
Lux will fetch sources from the
variables: Option<Vec<(String, String)>>Override config variables.{n}
Example: lx -v "LUA=/path/to/lua" ...
verbose: boolDisplay verbose output of commands executed.
no_progress: boolDon’t print any progress bars or spinners.
nvim: boolConfigure lux for installing Neovim packages.
timeout: Option<usize>Timeout on network operations, in seconds.{n} 0 means no timeout (wait forever). Default is 30.
max_jobs: Option<usize>Maximum buffer size for parallel jobs, such as downloading rockspecs and installing rocks. 0 means no limit. Default is 0.
no_luarc: boolDo not generate or update a .luarc.json file when building{n}
a project.
command: CommandsTrait Implementations
Sourceimpl Args for Cli
impl Args for Cli
Sourcefn augment_args<'b>(__clap_app: Command) -> Command
fn augment_args<'b>(__clap_app: Command) -> Command
Sourcefn augment_args_for_update<'b>(__clap_app: Command) -> Command
fn augment_args_for_update<'b>(__clap_app: Command) -> Command
Command so it can instantiate self via
FromArgMatches::update_from_arg_matches_mut Read moreSourceimpl CommandFactory for Cli
impl CommandFactory for Cli
Sourceimpl FromArgMatches for Cli
impl FromArgMatches for Cli
Sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
Sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches,
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches, ) -> Result<Self, Error>
Sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches, ) -> Result<(), Error>
ArgMatches to self.Sourcefn update_from_arg_matches_mut(
&mut self,
__clap_arg_matches: &mut ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches_mut( &mut self, __clap_arg_matches: &mut ArgMatches, ) -> Result<(), Error>
ArgMatches to self.Sourceimpl Parser for Cli
impl Parser for Cli
Sourcefn parse_from<I, T>(itr: I) -> Self
fn parse_from<I, T>(itr: I) -> Self
Sourcefn try_parse_from<I, T>(itr: I) -> Result<Self, Error>
fn try_parse_from<I, T>(itr: I) -> Result<Self, Error>
Sourcefn update_from<I, T>(&mut self, itr: I)
fn update_from<I, T>(&mut self, itr: I)