current_workspace_or_user_tree

Function current_workspace_or_user_tree 

pub fn current_workspace_or_user_tree(config: &Config) -> Result<Tree>
Get the current workspaces tree, or fall back to the user tree if not in a project