pub struct Cli {Show 14 fields
pub dev: bool,
pub server: Option<Url>,
pub extra_servers: Option<Vec<Url>>,
pub only_sources: Option<String>,
pub namespace: Option<String>,
pub lua_dir: Option<PathBuf>,
pub lua_version: Option<LuaVersion>,
pub tree: Option<PathBuf>,
pub cache_path: Option<PathBuf>,
pub no_project: bool,
pub verbose: bool,
pub nvim: bool,
pub timeout: Option<usize>,
pub command: Commands,
}Expand description
A luxurious package manager for Lua.
Fields
dev: boolEnable the sub-repositories in luarocks servers for rockspecs of in-development versions.
server: Option<Url>Fetch rocks/rockspecs from this server (takes priority over config file).
extra_servers: Option<Vec<Url>>Fetch rocks/rockspecs from this server in addition to the main server (overrides any entries in the config file).
only_sources: Option<String>Restrict downloads to paths matching the given URL.
namespace: Option<String>Specify the luarocks server namespace to use.
lua_dir: Option<PathBuf>Specify the luarocks server namespace to use.
lua_version: Option<LuaVersion>Which Lua installation to use. Valid versions are: ‘5.1’, ‘5.2’, ‘5.3’, ‘5.4’, ‘jit’ and ‘jit52’.
tree: Option<PathBuf>Which tree to operate on.
cache_path: Option<PathBuf>Specifies the cache directory for e.g. luarocks manifests.
no_project: boolDo not use project tree even if running from a project folder.
verbose: boolDisplay verbose output of commands executed.
nvim: boolConfigure lux for installing Neovim packages.
timeout: Option<usize>Timeout on network operations, in seconds. 0 means no timeout (wait forever). Default is 30.
command: CommandsTrait Implementations
Sourceimpl Args for Cli
impl Args for Cli
Sourcefn augment_args<'b>(__clap_app: Command) -> Command
fn augment_args<'b>(__clap_app: Command) -> Command
Sourcefn augment_args_for_update<'b>(__clap_app: Command) -> Command
fn augment_args_for_update<'b>(__clap_app: Command) -> Command
Command so it can instantiate self via
FromArgMatches::update_from_arg_matches_mut Read moreSourceimpl CommandFactory for Cli
impl CommandFactory for Cli
Sourceimpl FromArgMatches for Cli
impl FromArgMatches for Cli
Sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
Sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches,
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches, ) -> Result<Self, Error>
Sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches, ) -> Result<(), Error>
ArgMatches to self.Sourcefn update_from_arg_matches_mut(
&mut self,
__clap_arg_matches: &mut ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches_mut( &mut self, __clap_arg_matches: &mut ArgMatches, ) -> Result<(), Error>
ArgMatches to self.Sourceimpl Parser for Cli
impl Parser for Cli
Sourcefn parse_from<I, T>(itr: I) -> Self
fn parse_from<I, T>(itr: I) -> Self
Sourcefn try_parse_from<I, T>(itr: I) -> Result<Self, Error>
fn try_parse_from<I, T>(itr: I) -> Result<Self, Error>
Sourcefn update_from<I, T>(&mut self, itr: I)
fn update_from<I, T>(&mut self, itr: I)