Module workspace

Module workspace 

Enums

PackageReqOrGitShorthand
Used for parsing alternatives between a git URL shorthand and a package requirement.

Functions

current_workspace_or_user_tree
Get the current workspaces tree, or fall back to the user tree if not in a project
sync_build_dependencies_if_locked
sync_dependencies_if_locked
sync_test_dependencies_if_locked
top_level_ignored_files